// This version of show uses MDI.

#include "show.h"

// ===========================================================
// The child window
// ===========================================================

DEFINE_RESPONSE_TABLE1(ImageWindow, TMDIChild)
	EV_WM_SIZE,
END_RESPONSE_TABLE;

// Constructor
ImageWindow::ImageWindow(TMDIClient& parent, char far* title)
	: TMDIChild(parent, title)
{
	strcpy(fName, title);
	OpenDib(fName);
}

void
ImageWindow::OpenDib(char far* fName) {
	TDib* pdib = new TDib(fName);  		// Load DIB file
	bitmap = new TBitmap(*pdib);      // Convert DIB to DDB bitmap
	delete pdib;                      // Done with DIB, so delete it
	SetCaption(fName);								// Update caption
	Scroller = new TScroller(this,
	 1, 1, bitmap->Width(), bitmap->Height());
	 Invalidate();
}

// Destructor
ImageWindow::~ImageWindow()
{
	delete bitmap;
}

// Setup child window size
void
ImageWindow::SetupWindow() {
}

// Paint or repaint window contents
// Scrolling is automatic
void
ImageWindow::Paint(TDC& dc, BOOL /*erase*/, TRect& /*rect*/)
{
	TMemoryDC memdc(dc);
	memdc.SelectObject(*bitmap);
	dc.BitBlt(0, 0,
	 bitmap->Width(), bitmap->Height(), memdc, 0, 0, SRCCOPY);
	AdjustScrollers();
}

// Respond to WM_SIZE message
// Limit scroller ranges to window and bitmap sizes
void
ImageWindow::EvSize(UINT sizeType, TSize& size)
{
	TMDIChild::EvSize(sizeType, size);
	AdjustScrollers();
}

// Adjust horizontal and vertical scroller ranges
void
ImageWindow::AdjustScrollers()
{
	TRect tr;   // Rectangle for client area dimensions
	long H, W;  // Document size minus window in display units

	GetClientRect(tr);
	W = bitmap->Width() - (tr.right - tr.left);
	H = bitmap->Height() - (tr.bottom - tr.top);
	Scroller->SetRange(W / Scroller->XUnit, H / Scroller->YUnit);
	SetScrollPos(SB_HORZ, (int)Scroller->XPos, TRUE);
	SetScrollPos(SB_VERT, (int)Scroller->YPos, TRUE);
}

// ===========================================================
// The client window
// ===========================================================

DEFINE_RESPONSE_TABLE1(ImageFrame, TMDIClient)
	EV_WM_SIZE,
	EV_CHILD_NOTIFY(IDC_PUSHBUTTON_NORTH, BN_CLICKED, OnNorth),
	EV_CHILD_NOTIFY(IDC_PUSHBUTTON_SOUTH, BN_CLICKED, OnSouth),
END_RESPONSE_TABLE;

ImageFrame::~ImageFrame() {
	delete iw;
	delete dialog;
	Destroy();
}

// Create an initial empty child
void
ImageFrame::SetupWindow() {
	TWindow::SetupWindow();
	TRect ClientRect;   // Rectangle for client area dimensions
	::GetClientRect(GetParent(), &ClientRect);

	dialog = new TMDIChild(*this, "Select", new TMainDlg(this, IDD_MAINDLG), true);
	iw = new ImageWindow(*this, FILENAME1);

	iw->Attr.X = ClientRect.left;
	iw->Attr.Y = ClientRect.top;
	iw->Attr.W = ClientRect.right;
	iw->Attr.H = ClientRect.bottom - SEPARATEBORDER;
	iw->Attr.Style |= WS_VSCROLL | WS_HSCROLL;

	TRect dialogRect(ClientRect.left, ClientRect.bottom -
				SEPARATEBORDER, ClientRect.right, ClientRect.bottom);

	iw->Create();
	dialog->Create();
	dialog->MoveWindow(dialogRect);
}

// Load bitmap 1
void
ImageFrame::OnNorth() {
	iw->OpenDib(FILENAME1);
}

// Load bitmap 2
void
ImageFrame::OnSouth() {
	iw->OpenDib(FILENAME2);
}

// ===========================================================
// The frame window
// ===========================================================

TMyMDIFrame::TMyMDIFrame(const char far* title,
							TResId          menuResId,
							TMDIClient&     clientWnd):
							TMDIFrame(title, menuResId, clientWnd) {
	TRect ScreenRect;   // Rectangle for screen area dimensions
	::GetWindowRect(GetDesktopWindow(), &ScreenRect);
	Attr.X = ScreenRect.left;
	Attr.Y = ScreenRect.top;
	Attr.W = ScreenRect.right;
	Attr.H = ScreenRect.bottom;
}

// ===========================================================
// The application class
// ===========================================================

class TShowBitApp: public TApplication {
public:
	TShowBitApp(const char far* name)
		: TApplication(name) {};
	void InitMainWindow();
private:
	ImageFrame* client;
};

// Initialize the program's main window
void
TShowBitApp::InitMainWindow()
{
	client = new ImageFrame;
	MainWindow = new TMyMDIFrame("Show", ID_MENU, *client);

// Menu associated with window
	MainWindow->AssignMenu(ID_MENU);

// Assign icon with this application
	MainWindow->SetIcon(this, IDI_MDIAPPLICATION);

}

#pragma argsused

// Main program
int
OwlMain(int argc, char* argv[])
{
	TShowBitApp app("Show");
  return app.Run();
}

